@@ -2,7 +2,7 @@
  * command.c
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
- * $Id: command.c,v 1.19 2003/11/14 04:50:37 nrt Exp $
+ * $Id: command.c,v 1.20 2004/01/05 07:42:31 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -76,8 +76,6 @@
 
 private file_t *f;		/* current file */
 
-#define FILE_MAX		128
-
 typedef struct FILE_LIST_T {
   char *name;
   file_t *file;
@@ -336,7 +334,7 @@ private boolean_t CommandGetNumber( unsigned int *number, int *newCom )
 
   for( ; ; ){
     if( 0 == n )
-      buf[ 0 ] = NULL;
+      buf[ 0 ] = 0x00;
     else
       sprintf( buf, "%u", n );
 
@@ -526,7 +524,7 @@ private void CommandReload( unsigned int arg )
   pathnameCodingSystem = f->pathnameCodingSystem;
   defaultCodingSystem = f->defaultCodingSystem;
 
-  logical = 1 + f->screen.top.seg * PAGE_SIZE + f->screen.top.off;
+  logical = 1 + f->screen.top.seg * LV_PAGE_SIZE + f->screen.top.off;
 
   CommandSavePattern();
 
@@ -567,23 +565,23 @@ private int CommandLaunchEditor( byte *editor, byte *filename, int line )
 
   ptr = com;
   argc = 0;
-  while( NULL != *ptr && argc < ARG_SIZE - 2 ){
+  while( 0x00 != *ptr && argc < ARG_SIZE - 2 ){
     argv[ argc ] = ptr;
-    while( ' ' != *ptr && NULL != *ptr )
+    while( ' ' != *ptr && 0x00 != *ptr )
       ptr++;
-    if( NULL != *ptr ){
-      *ptr++ = NULL;
-      while( ' ' == *ptr && NULL != *ptr )
+    if( 0x00 != *ptr ){
+      *ptr++ = 0x00;
+      while( ' ' == *ptr && 0x00 != *ptr )
 	ptr++;
     }
-    if( NULL != (nptr = strchr( argv[ argc ], '%' )) && 'd' == *(++nptr ) ){
+    if( 0x00 != (nptr = strchr( argv[ argc ], '%' )) && 'd' == *(++nptr ) ){
       sprintf( num, argv[ argc ], line );
       argv[ argc ] = num;
     }
     argc++;
   }
   argv[ argc++ ] = filename;
-  argv[ argc ] = NULL;
+  argv[ argc ] = 0x00;
 
 #ifdef NOT
   {
@@ -635,7 +633,7 @@ private void CommandEdit( unsigned int arg )
   ConsoleShellEscape();
 
   fileName = f->fileName;
-  lineNumber = 1 + f->screen.top.seg * PAGE_SIZE + f->screen.top.off;
+  lineNumber = 1 + f->screen.top.seg * LV_PAGE_SIZE + f->screen.top.off;
 
   CommandSavePattern();
   FileRefresh( f );
@@ -717,7 +715,7 @@ private void CommandPoll( unsigned int arg )
     ConsoleClearRight();
     ConsoleSetAttribute( ATTR_STANDOUT );
     ConsolePrints( "Waiting for data, break (^C) to return..." );
-    ConsoleSetAttribute( NULL );
+    ConsoleSetAttribute( 0 );
     ConsoleFlush();
 
     (void)fseek( f->fp, 0, SEEK_END );
@@ -838,7 +836,7 @@ private void CommandFileStatus( unsigned int arg )
 
     PositionAssign( pos, f->screen.top );
     ConsoleEnableInterrupt();
-    FileStretch( f, PAGE_SIZE * SLOT_SIZE );
+    FileStretch( f, LV_PAGE_SIZE * SLOT_SIZE );
     ConsoleDisableInterrupt();
     ScreenTopPhysical( f, &pos );
   }
@@ -923,27 +921,27 @@ private void CommandCursor( unsigned int arg )
       break;
     }
     step++;
-    if( TRUE == flagLeft && NULL == cur_left[ step ] ){
+    if( TRUE == flagLeft && 0x00 == cur_left[ step ] ){
       CommandPrevHalf( arg );
       break;
     }
-    if( TRUE == flagRight && NULL == cur_right[ step ] ){
+    if( TRUE == flagRight && 0x00 == cur_right[ step ] ){
       CommandNextHalf( arg );
       break;
     }
-    if( TRUE == flagUp && NULL == cur_up[ step ] ){
+    if( TRUE == flagUp && 0x00 == cur_up[ step ] ){
       CommandPrevLine( arg );
       break;
     }
-    if( TRUE == flagDown && NULL == cur_down[ step ] ){
+    if( TRUE == flagDown && 0x00 == cur_down[ step ] ){
       CommandNextLine( arg );
       break;
     }
-    if( TRUE == flagPpage && NULL == cur_ppage[ step ] ){
+    if( TRUE == flagPpage && 0x00 == cur_ppage[ step ] ){
       CommandPrevPage( arg );
       break;
     }
-    if( TRUE == flagNpage && NULL == cur_npage[ step ] ){
+    if( TRUE == flagNpage && 0x00 == cur_npage[ step ] ){
       CommandNextPage( arg );
       break;
     }
@@ -1167,7 +1165,7 @@ public void Command( file_t *file, byte **optional )
     if( NULL != label ){
       ConsoleSetAttribute( ATTR_STANDOUT );
       ConsolePrints( label );
-      ConsoleSetAttribute( NULL );
+      ConsoleSetAttribute( 0 );
       label = NULL;
     }
 
@@ -1176,7 +1174,7 @@ public void Command( file_t *file, byte **optional )
     if( NULL != message ){
       ConsoleSetAttribute( ATTR_STANDOUT );
       ConsolePrints( message );
-      ConsoleSetAttribute( NULL );
+      ConsoleSetAttribute( 0 );
       message = NULL;
     }
 
