@@ -2,7 +2,7 @@
  * file.h
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio
- * $Id: file.h,v 1.7 2003/11/13 03:08:19 nrt Exp $
+ * $Id: file.h,v 1.8 2004/01/05 07:30:15 nrt Exp $
  */
 
 #ifndef __FILE_H__
@@ -15,7 +15,7 @@
 #include <str.h>
 #include <stream.h>
 
-#define PAGE_SIZE	32U		/* lines per page */
+#define LV_PAGE_SIZE	32U		/* lines per page */
 
 #ifdef MSDOS
 #define BLOCK_SIZE	2		/* segments on memory */
@@ -42,7 +42,7 @@ typedef struct {
 typedef struct {
   unsigned int	segment;
   int		lines;			/* logical line number */
-  line_t	line[ PAGE_SIZE ];
+  line_t	line[ LV_PAGE_SIZE ];
 } page_t;
 
 typedef struct {
@@ -107,8 +107,8 @@ typedef struct {
 #endif /* far */
 #endif /* MSDOS */
 
-#define Segment( line )		( (line) / PAGE_SIZE )
-#define Offset( line )		( (line) % PAGE_SIZE )
+#define Segment( line )		( (line) / LV_PAGE_SIZE )
+#define Offset( line )		( (line) % LV_PAGE_SIZE )
 #define Block( segment )	( (segment) % BLOCK_SIZE )
 #define Slot( segment )		( (segment) % SLOT_SIZE )
 #define Frame( segment )	( (segment) / SLOT_SIZE )
