@@ -2,7 +2,7 @@
  * find.c
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
- * $Id: find.c,v 1.5 2003/11/13 03:08:19 nrt Exp $
+ * $Id: find.c,v 1.6 2004/01/05 07:30:15 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -265,7 +265,7 @@ private boolean_t FindContinue( file_t *f, position_t *pos, boolean_t forward )
 #endif /* MSDOS */
     if( TRUE == kb_interrupted )
       break;
-    for( offset = 0 ; offset < PAGE_SIZE && FALSE == f->eof ; offset++ ){
+    for( offset = 0 ; offset < LV_PAGE_SIZE && FALSE == f->eof ; offset++ ){
       str = FileLoadLine( f, &idx, &simple );
       if( 0 == idx )
 	return FALSE;
@@ -375,7 +375,7 @@ public int FindForward( file_t *f )
   if( TRUE == flagContinue ){
     if( TRUE == FindContinue( f, &pos, TRUE ) ){
       ConsoleDisableInterrupt();
-      ScreenTop( f, 1 + pos.seg * PAGE_SIZE + pos.off );
+      ScreenTop( f, 1 + pos.seg * LV_PAGE_SIZE + pos.off );
       PositionAssign( pos, f->screen.top );
       while( FALSE == f->page[ pos.blk ].line[ pos.off ].head[ pos.phy ].hit ){
 	PositionInc( f, pos.seg, pos.blk, pos.off, pos.phy );
@@ -467,7 +467,7 @@ public int FindBackward( file_t *f )
   if( TRUE == flagContinue ){
     if( TRUE == FindContinue( f, &pos, FALSE ) ){
       ConsoleDisableInterrupt();
-      ScreenTop( f, 1 + pos.seg * PAGE_SIZE + pos.off );
+      ScreenTop( f, 1 + pos.seg * LV_PAGE_SIZE + pos.off );
       PositionAssign( pos, f->screen.top );
       pos.phy = f->page[ pos.blk ].line[ pos.off ].heads - 1;
       while( FALSE == f->page[ pos.blk ].line[ pos.off ].head[ pos.phy ].hit ){
