@@ -2,7 +2,7 @@
  * iso2022.c
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
- * $Id: iso2022.c,v 1.5 2003/11/13 03:08:19 nrt Exp $
+ * $Id: iso2022.c,v 1.6 2004/01/05 07:23:29 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -76,7 +76,7 @@ public void DecodeISO2022( state_t *state, byte codingSystem )
 	}
       }
       rch = ch;
-      if( NULL != state->sset ){
+      if( 0 != state->sset ){
 	/*
 	 * single shifted character
 	 */
