@@ -2,7 +2,7 @@
  * iso2cn.c
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
- * $Id: iso2cn.c,v 1.3 2003/11/13 03:08:19 nrt Exp $
+ * $Id: iso2cn.c,v 1.4 2004/01/05 07:23:29 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -20,6 +20,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <stdio.h>
+
 #include <import.h>
 #include <encode.h>
 #include <unimap.h>
@@ -44,7 +46,7 @@ public void EncodeISO2022cn( i_str_t *istr, int head, int tail,
   byte cset, gl, lastCsetG1, lastCsetG2, lastCsetG3, shiftState;
   boolean_t set94;
 
-  attr = NULL;
+  attr = 0;
   gl = G0;
   lastCsetG1 = lastCsetG2 = lastCsetG3 = ASCII;
   shiftState = NUL;
