@@ -2,7 +2,7 @@
  * iso2jp.c
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
- * $Id: iso2jp.c,v 1.4 2003/11/13 03:08:19 nrt Exp $
+ * $Id: iso2jp.c,v 1.5 2004/01/05 07:23:29 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -42,7 +42,7 @@ public void EncodeISO2022jp( i_str_t *istr, int head, int tail,
   byte cset, lastCset, lastCsetG0, lastCsetG2;
   boolean_t lastSet94, set94, bit8 = FALSE;
 
-  attr = NULL;
+  attr = 0;
   lastCset = lastCsetG0 = lastCsetG2 = ASCII;
   lastSet94 = TRUE;
 
