@@ -2,7 +2,7 @@
  * istr.c
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
- * $Id: istr.c,v 1.7 2003/11/13 03:08:19 nrt Exp $
+ * $Id: istr.c,v 1.8 2004/01/05 07:30:15 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -41,7 +41,7 @@
 
 #define STUB_SIZE		( STUB_SPARE + 1 )
 
-#define STUB_SPARE_SEGS		( PAGE_SIZE + 1 )
+#define STUB_SPARE_SEGS		( LV_PAGE_SIZE + 1 )
 
 typedef struct {
   int blockSize;
@@ -80,7 +80,7 @@ public void IstrInit()
    */
   for( zone = 0 ; zone < ZONE_SIZE ; zone++ ){
     blockSize = STR_SIZE;
-    segmentMax = PAGE_SIZE;
+    segmentMax = LV_PAGE_SIZE;
 
     for( i = STUB_SPARE ; i >= 0 ; i-- ){
       if( 0 == blockSize || 0 == segmentMax )
