@@ -1,8 +1,8 @@
 /*
  * itable.c
  *
- * All rights reserved. Copyright (C) 1996-1999 by NARITA Tomio.
- * $Id: itable.c,v 1.4 2000/06/26 11:52:23 nrt Exp $
+ * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
+ * $Id: itable.c,v 1.6 2003/11/13 03:08:19 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -46,6 +46,12 @@ public i_table_t iTable[ I_TABLE_SIZE ] = {
   { ISO8859_7,	'F', FALSE, SET96, 1, 1 },
   { ISO8859_8,	'H', FALSE, SET96, 1, 1 },
   { ISO8859_9,	'M', FALSE, SET96, 1, 1 },
+  { ISO8859_10,	'V', FALSE, SET96, 1, 1 },
+  { ISO8859_11,	'T', FALSE, SET96, 1, 1 },
+  { ISO8859_13,	'Y', FALSE, SET96, 1, 1 },
+  { ISO8859_14,	'_', FALSE, SET96, 1, 1 },
+  { ISO8859_15,	'b', FALSE, SET96, 1, 1 },
+  { ISO8859_16,	'f', FALSE, SET96, 1, 1 },
 
   { C6226,	'@', TRUE,  SET94, 2, 2 },
   { GB2312,	'A', TRUE,  SET94, 2, 2 },
@@ -120,6 +126,7 @@ public byte ItableLookup( byte fin, boolean_t multi, boolean_t set94 )
       if( iTableCacheIndex >= I_TABLE_CACHE_SIZE )
 	iTableCacheIndex = 0;
       iTableCache[ iTableCacheIndex ] = iTable[ i ];
+      iTableCacheUsed[ iTableCacheIndex ] = TRUE;
 
       return i;
     }
