@@ -1,8 +1,8 @@
 /*
  * keybind.h
  *
- * All rights reserved. Copyright (C) 1996-1999 by NARITA Tomio
- * $Id: keybind.h,v 1.4 2000/06/26 11:54:19 nrt Exp $
+ * All rights reserved. Copyright (C) 1996 by NARITA Tomio
+ * $Id: keybind.h,v 1.6 2003/11/13 03:08:19 nrt Exp $
  */
 
 #ifndef __KEYBIND_H__
@@ -81,7 +81,7 @@ private key_table_t keyTable[ 128 ] = {
   CommandNull,		/* 'C' */
   CommandNull,		/* 'D' */
   CommandNull,		/* 'E' */
-  CommandNull,		/* 'F' */
+  CommandPoll,		/* 'F' */
   CommandBottomOfFile,	/* 'G' */
   CommandPrevLine,	/* 'H' */
   CommandNull,		/* 'I' */
