@@ -2,7 +2,7 @@
  * lv.c
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
- * $Id: lv.c,v 1.9 2003/11/13 03:08:19 nrt Exp $
+ * $Id: lv.c,v 1.10 2004/01/05 07:30:15 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -76,9 +76,9 @@ private void LvInit( byte **argv )
   ConfInit( (unsigned char **)argv );
 
   if( NULL != (ptr = strrchr( argv[ 0 ], '/' )) )
-    *ptr++ = NULL;
+    *ptr++ = 0x00;
   else if( NULL != (ptr = strrchr( argv[ 0 ], '\\' )) )
-    *ptr++ = NULL;
+    *ptr++ = 0x00;
   else
     ptr = argv[ 0 ];
 
@@ -176,8 +176,8 @@ private boolean_t LvView( conf_t *conf )
   if( conf->width > 0 ) WIDTH = conf->width;
   if( conf->height > 0 ) HEIGHT = conf->height;
 
-  if( HEIGHT > PAGE_SIZE * ( BLOCK_SIZE - 1 ) )
-    HEIGHT = PAGE_SIZE * ( BLOCK_SIZE - 1 );
+  if( HEIGHT > LV_PAGE_SIZE * ( BLOCK_SIZE - 1 ) )
+    HEIGHT = LV_PAGE_SIZE * ( BLOCK_SIZE - 1 );
 
   if( TRUE == conf->keyCodingSystemVirgin )
     conf->keyboardCodingSystem = conf->outputCodingSystem;
