@@ -9,7 +9,7 @@
 
 # Unicode to KSC 5601-1987
 
-$file = "zcat OLD5601.TXT.gz |";
+$file = "zcat KSX1001.TXT.gz |";
 
 for $i ( 0 .. $#ARGV ){
   if( $ARGV[ $i ] eq "-i" ){
