@@ -2,7 +2,7 @@
  * position.h
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio
- * $Id: position.h,v 1.4 2003/11/13 03:08:19 nrt Exp $
+ * $Id: position.h,v 1.5 2004/01/05 07:30:15 nrt Exp $
  */
 
 #ifndef __POSITION_H__
@@ -47,7 +47,7 @@
 	 */								\
 	break;								\
       } else {								\
-	if( FALSE == FetchLine( (f), (seg) - 1, PAGE_SIZE - 1 ) ){	\
+	if( FALSE == FetchLine( (f), (seg) - 1, LV_PAGE_SIZE - 1 ) ){	\
 	  /*								\
 	   * memory shortage?						\
 	   */								\
