@@ -2,7 +2,7 @@
  * raw.c
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
- * $Id: raw.c,v 1.5 2003/11/13 03:08:19 nrt Exp $
+ * $Id: raw.c,v 1.6 2004/01/05 07:23:29 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -20,6 +20,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <stdio.h>
+
 #include <import.h>
 #include <decode.h>
 #include <encode.h>
@@ -33,14 +35,14 @@ public void DecodeRaw( state_t *state, byte codingSystem )
   for( ; ; ){
     GetChar( ch );
     if( SP == ch ){
-      DecodeAddSpace( NULL );
+      DecodeAddSpace( 0 );
     } else if( HT == ch ){
-      DecodeAddTab( NULL );
+      DecodeAddTab( 0 );
     } else if( ch < SP || ch >= DEL ){
       DecodeAddControl( ch );
     } else {
       c[ 0 ] = ch;
-      DecodeAddChar( ASCII, c, NULL );
+      DecodeAddChar( ASCII, c, 0 );
     }
   }
 }
