@@ -2,7 +2,7 @@
  * screen.c
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
- * $Id: screen.c,v 1.3 2003/11/13 03:08:19 nrt Exp $
+ * $Id: screen.c,v 1.4 2004/01/05 07:36:02 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -115,7 +115,7 @@ public boolean_t ScreenBot( file_t *f )
 
   if( FALSE == f->done ){
     ConsoleEnableInterrupt();
-    FileStretch( f, PAGE_SIZE * SLOT_SIZE * FRAME_SIZE - 1 );
+    FileStretch( f, LV_PAGE_SIZE * SLOT_SIZE * FRAME_SIZE - 1 );
     ConsoleDisableInterrupt();
   }
 
@@ -167,9 +167,7 @@ public boolean_t ScreenTop( file_t *f, unsigned int logical )
   ConsoleDisableInterrupt();
 
   if( FALSE == res ){
-    if( FALSE == kb_interrupted )
-      return ScreenBot( f );
-    logical = f->lastSegment * PAGE_SIZE;
+    return ScreenBot( f );
   }
 
   seg = Segment( logical );
@@ -246,12 +244,12 @@ public void ScreenRefresh( file_t *f )
 
   ConsoleGetWindowSize();
 
-  if( HEIGHT > PAGE_SIZE * ( BLOCK_SIZE - 1 ) )
-    HEIGHT = PAGE_SIZE * ( BLOCK_SIZE - 1 );
+  if( HEIGHT > LV_PAGE_SIZE * ( BLOCK_SIZE - 1 ) )
+    HEIGHT = LV_PAGE_SIZE * ( BLOCK_SIZE - 1 );
 
   f->width = WIDTH;
   f->height = HEIGHT - 1;
 
-  logical = 1 + f->screen.top.seg * PAGE_SIZE + f->screen.top.off;
+  logical = 1 + f->screen.top.seg * LV_PAGE_SIZE + f->screen.top.off;
   ScreenTop( f, logical );
 }
