@@ -2,7 +2,7 @@
  * shiftjis.c
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
- * $Id: shiftjis.c,v 1.6 2003/11/13 03:08:19 nrt Exp $
+ * $Id: shiftjis.c,v 1.7 2004/01/05 07:23:29 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -20,6 +20,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include <stdio.h>
+
 #include <import.h>
 #include <decode.h>
 #include <escape.h>
@@ -77,7 +79,7 @@ public void DecodeShiftJis( state_t *state, byte codingSystem )
       else
 	DecodeAddControl( ch );
     } else {
-      if( NULL != state->sset ){
+      if( 0 != state->sset ){
 	if( FALSE == DecodeAddShifted( state, ch ) )
 	  break;
 	else
