@@ -2,7 +2,7 @@
  * uty.c
  *
  * All rights reserved. Copyright (C) 1996 by NARITA Tomio.
- * $Id: uty.c,v 1.5 2003/11/13 03:08:19 nrt Exp $
+ * $Id: uty.c,v 1.6 2004/01/05 07:23:29 nrt Exp $
  */
 /*
  * This program is free software; you can redistribute it and/or modify
@@ -106,7 +106,7 @@ public byte *TokenAlloc( byte *s )
   int i, j;
   byte *token;
   boolean_t flagQuotation;
-  byte quotationChar = NULL;
+  byte quotationChar = 0;
 
   if( '\'' == *s || '"' == *s ){
     flagQuotation = TRUE;
@@ -116,7 +116,7 @@ public byte *TokenAlloc( byte *s )
     flagQuotation = FALSE;
 
   for( i = 0 ; i < TOKEN_LENGTH ; i++ ){
-    if( NULL == s[ i ] )
+    if( 0x00 == s[ i ] )
       break;
     if( FALSE == flagQuotation  ){
       if( ' ' == s[ i ] || 0x09 == s[ i ] )
@@ -132,7 +132,7 @@ public byte *TokenAlloc( byte *s )
   token = (byte *)Malloc( i + 1 );
   for( j = 0 ; j < i ; j++ )
     token[ j ] = s[ j ];
-  token[ j ] = NULL;
+  token[ j ] = 0x00;
 
   return token;
 }
